==> haskell-tasty-quickcheck-0.10.2-349.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-quickcheck
version:              0.10.2
visibility:           public
id:                   tasty-quickcheck-0.10.2-L6db6j4Sm1k5Ktj8Km8XJK
key:                  tasty-quickcheck-0.10.2-L6db6j4Sm1k5Ktj8Km8XJK
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.
category:             Testing
abi:                  af2cfa8064ec3077de9d357345977fb0
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-quickcheck-0.10.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-quickcheck-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.10.2-L6db6j4Sm1k5Ktj8Km8XJK
depends:
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED base-4.16.4.0
    optparse-applicative-0.17.1.0-H9wWDnSwLoeC3JH97ZHNAY
    random-1.2.1.2-JIamRYdFYdY4e3nutT9Pr4
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    tasty-1.4.3-45V6IUrFvI6FX8Qf0XPHba

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.10.2-358.3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-quickcheck
version:              0.10.2
visibility:           public
id:                   tasty-quickcheck-0.10.2-ExbJ6yxkvAsLgKVnfS6xoz
key:                  tasty-quickcheck-0.10.2-ExbJ6yxkvAsLgKVnfS6xoz
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.
category:             Testing
abi:                  18b0e039a0286b5d19dfb09d2f565bf5
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-quickcheck-0.10.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-quickcheck-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.10.2-ExbJ6yxkvAsLgKVnfS6xoz
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    optparse-applicative-0.17.1.0-AgMeQrX7nmlDOnX2xcegDb
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
